@@ -1,8 +1,8 @@
 use crate::client::*;
-use crate::test_struct::{LogOn, LogOnResult, Foo};
+use crate::test_struct::{Foo, LogOn, LogOnResult};
 use anyhow::Result;
 use log::*;
-use netxserver::*;
+use netxserver::prelude::*;
 use std::cell::Cell;
 use std::sync::Arc;
 use tcpserver::IPeer;
@@ -17,19 +17,30 @@ pub trait ITestController {
     async fn closed(&self) -> Result<()>;
 
     #[tag(1)]
-    async fn test_base_type(&self,v:(bool,i8,u8,i16,u16,i32,u32,i64,u64,f32,f64))->Result<(bool,i8,u8,i16,u16,i32,u32,i64,u64,f32,f64)>;
+    async fn test_base_type(
+        &self,
+        v: (bool, i8, u8, i16, u16, i32, u32, i64, u64, f32, f64),
+    ) -> Result<(bool, i8, u8, i16, u16, i32, u32, i64, u64, f32, f64)>;
     #[tag(2)]
-    async fn test_string(&self,v:(String,Option<String>,Option<String>))->Result<(String,Option<String>,Option<String>)>;
+    async fn test_string(
+        &self,
+        v: (String, Option<String>, Option<String>),
+    ) -> Result<(String, Option<String>, Option<String>)>;
     #[tag(3)]
-    async fn test_buff(&self,v:(Vec<u8>,Option<Vec<u8>>,Option<Vec<u8>>))->Result<(Vec<u8>, Option<Vec<u8>>, Option<Vec<u8>>)>;
+    async fn test_buff(
+        &self,
+        v: (Vec<u8>, Option<Vec<u8>>, Option<Vec<u8>>),
+    ) -> Result<(Vec<u8>, Option<Vec<u8>>, Option<Vec<u8>>)>;
     #[tag(4)]
-    async fn test_struct(&self,foo:Foo)->Result<Foo>;
+    async fn test_struct(&self, foo: Foo) -> Result<Foo>;
 
     #[tag(5)]
-    async fn test_base_type2(&self,v:(i64,u64,f32,f64))->Result<(i64,u64,f32,f64)>;
+    async fn test_base_type2(&self, v: (i64, u64, f32, f64)) -> Result<(i64, u64, f32, f64)>;
     #[tag(6)]
-    async fn test_base_type3(&self,v:(bool,i8,u8,i16,u16,i32,u32))->Result<(bool,i8,u8,i16,u16,i32,u32)>;
-
+    async fn test_base_type3(
+        &self,
+        v: (bool, i8, u8, i16, u16, i32, u32),
+    ) -> Result<(bool, i8, u8, i16, u16, i32, u32)>;
 
     #[tag(600)]
     async fn print2(&self, a: i32, b: String) -> Result<()>;
@@ -109,18 +120,27 @@ impl ITestController for TestController {
     }
 
     #[inline]
-    async fn test_base_type(&self, v: (bool, i8, u8, i16, u16, i32, u32, i64, u64, f32, f64)) -> Result<(bool, i8, u8, i16, u16, i32, u32, i64, u64, f32, f64)> {
+    async fn test_base_type(
+        &self,
+        v: (bool, i8, u8, i16, u16, i32, u32, i64, u64, f32, f64),
+    ) -> Result<(bool, i8, u8, i16, u16, i32, u32, i64, u64, f32, f64)> {
         println!("{:?}", v);
         Ok(v)
     }
 
     #[inline]
-    async fn test_string(&self, v: (String, Option<String>, Option<String>)) -> Result<(String, Option<String>, Option<String>)> {
+    async fn test_string(
+        &self,
+        v: (String, Option<String>, Option<String>),
+    ) -> Result<(String, Option<String>, Option<String>)> {
         println!("{:?}", v);
         Ok(v)
     }
 
-    async fn test_buff(&self, v: (Vec<u8>, Option<Vec<u8>>, Option<Vec<u8>>)) -> Result<(Vec<u8>, Option<Vec<u8>>, Option<Vec<u8>>)> {
+    async fn test_buff(
+        &self,
+        v: (Vec<u8>, Option<Vec<u8>>, Option<Vec<u8>>),
+    ) -> Result<(Vec<u8>, Option<Vec<u8>>, Option<Vec<u8>>)> {
         println!("{:?}", v);
         Ok(v)
     }
@@ -135,12 +155,14 @@ impl ITestController for TestController {
         Ok(v)
     }
 
-    async fn test_base_type3(&self, v: (bool, i8, u8, i16, u16, i32, u32)) -> Result<(bool, i8, u8, i16, u16, i32, u32)> {
+    async fn test_base_type3(
+        &self,
+        v: (bool, i8, u8, i16, u16, i32, u32),
+    ) -> Result<(bool, i8, u8, i16, u16, i32, u32)> {
         println!("{:?}", v);
         Ok(v)
     }
 
-
     #[inline]
     async fn print2(&self, a: i32, b: String) -> Result<()> {
         self.client.print2(a, &b).await
@@ -148,9 +170,9 @@ impl ITestController for TestController {
 
     #[inline]
     async fn run_test(&self, a: Option<String>) -> Result<()> {
-        println!("{:?}",a);
-        let p= self.client.run(a).await?;
-        println!("{:?}",p);
+        println!("{:?}", a);
+        let p = self.client.run(a).await?;
+        println!("{:?}", p);
         Ok(())
     }
 
